# March 29, 2022

**Date:** March 29, 2022, at 8am Pacific (your [timezone](https://arewemeetingyet.com/Los%20Angeles/2022-03-29/8:00/Jupyter%20Community%20Call))

**[Discourse](https://discourse.jupyter.org/t/jupyter-community-calls/668)**

There is no recording for this call.

**Please note:**
- Community calls are recorded and posted to this [playlist](https://www.youtube.com/playlist?list=PLUrHeD2K9Cmkoamm4NjLmvXC4Y6E1o8SP)
- These notes will be recorded and posted [here](https://jupyter.readthedocs.io/en/latest/community/community-call-notes/index.html)
- Everyone present is held to the [Jupyter Code of Conduct](https://jupyter.org/conduct)

## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

This is a place to make short announcements (without a need for discussion). 

* **Zach** [voila-gridstack](https://github.com/voila-dashboards/voila-gridstack) is great and Zach can't wait for a release on PyPI sometime soon!
    * [viola-dashboards/voila #846 Switch to a lab-based app for the Voila frontend ](https://github.com/voila-dashboards/voila/pull/846)

## Agenda Items

With time changes, this meeting was accidentally double-booked with the Jupyter Security meeting! Since we had an open agenda before the community call, our notes overlap with theirs.

For notes from this call, please refer to the [March 29, 2022 jupyter/security meeting notes!](https://github.com/jupyter/security/tree/main/meetings/2022-03-29.md)